@@ -1,7 +1,7 @@
 package WG::API::WoT;
 
 use Moo;
-extends 'WG::API';
+
 with 'WG::API::WoT::Account';
 with 'WG::API::WoT::Ratings';
 with 'WG::API::WoT::Tanks';
@@ -12,11 +12,11 @@ WG::API::WoT - Modules to work with Wargaming.net Public API for World of Tanks
 
 =head1 VERSION
 
-Version v0.8.1
+Version v0.8.3
 
 =cut
 
-our $VERSION = 'v0.8.1';
+our $VERSION = 'v0.8.3';
 
 
 =head1 SYNOPSIS
@@ -37,7 +37,7 @@ This module provide access to WG Public API
 
 =head2 new
 
-Create new object with params. Rerquired application id: L<http://ru.wargaming.net/developers/documentation/guide/getting-started/>
+Create new object with params. Rerquired application id: L<https://developers.wargaming.net/documentation/guide/getting-started/>
 
 Params:
 
@@ -52,6 +52,8 @@ has api_uri => (
     default => sub{ 'api.worldoftanks.ru/wot' },
 );
 
+with 'WG::API::Base';
+
 =head1 METHODS
 
 =head2 Account
@@ -155,7 +157,7 @@ L<http://search.cpan.org/dist/WG-API/>
 
 =head1 SEE ALSO
 
-WG API Reference L<http://ru.wargaming.net/developers/>
+WG API Reference L<https://developers.wargaming.net/>
 
 =head1 AUTHOR
 
